==> 1.0.5.tar.gz: lib/model/paycaps_request.dart <==
part of paycaps;

class PayCapsRequest {
  //Merchant Details**
  String merPayId = "";
  String orderId = "";
  String returnUrl = "";
  String pgURL = "";
  String merKey = "";

  //Customer Details**
  String custName = "";
  String custFirstName = "";
  String custLastName = "";
  String custAddress = "";
  String custCity = "";
  String custState = "";
  String custCountry = "";
  String custZip = "";
  String merCustEmail = "";
  String merCustPhone = "";

  //Optional property
  String custShipFirstName = "";
  String custShipLastName = "";
  String custShipName = "";
  String custShipAddress1 = "";
  String custShipAddress2 = "";
  String custShipCity = "";
  String custShipState = "";
  String custShipCountry = "";
  String custShipZip = "";
  String custShipPhone = "";

  //Payment Details**
  String amount = "";
  String currencyCode = "";

  //Item Level Field**
  String productDesc = "";

  PayCapsRequest({
    this.merPayId = "",
    this.orderId = "",
    this.returnUrl = "",
    this.pgURL = "",
    this.merKey = "",
    this.custName = "",
    this.custFirstName = "",
    this.custLastName = "",
    this.custAddress = "",
    this.custCity = "",
    this.custState = "",
    this.custCountry = "",
    this.custZip = "",
    this.merCustEmail = "",
    this.merCustPhone = "",
    this.custShipFirstName = "",
    this.custShipLastName = "",
    this.custShipName = "",
    this.custShipAddress1 = "",
    this.custShipAddress2 = "",
    this.custShipCity = "",
    this.custShipState = "",
    this.custShipCountry = "",
    this.custShipZip = "",
    this.custShipPhone = "",
    this.amount = "",
    this.currencyCode = "",
    this.productDesc = "",
  });

  String getRequestParameter() {
    try {
      Map<String, String> map = LinkedHashMap<String, String>();


      //Required field name for merchant details
      map["APP_ID"] = merPayId;
      map["ORDER_ID"] = orderId;
      map["RETURN_URL"] = returnUrl;
      map["HASH"] = PayCapsGetHash256().generateCheckSum(map, merKey);


      //Customer Details
      map["CUST_NAME"] = custName;
      map["CUST_FIRST_NAME"] = custFirstName;
      map["CUST_LAST_NAME"] = custLastName;
      map["CUST_STREET_ADDRESS1"] = custAddress;
      map["CUST_CITY"] = custCity;
      map["CUST_STATE"] = custState;
      map["CUST_COUNTRY"] = custCountry;
      map["CUST_ZIP"] = custZip;
      map["CUST_EMAIL"] = merCustEmail;
      map["CUST_PHONE"] = merCustPhone;
      map["CUST_SHIP_LAST_NAME"] = custShipLastName;
      map["CUST_SHIP_FIRST_NAME"] = custShipFirstName;
      map["CUST_SHIP_NAME"] = custShipName;
      map["CUST_SHIP_STREET_ADDRESS1"] = custShipAddress1;
      map["CUST_SHIP_STREET_ADDRESS2"] = custShipAddress2;
      map["CUST_SHIP_CITY"] = custShipCity;
      map["CUST_SHIP_STATE"] = custShipState;
      map["CUST_SHIP_COUNTRY"] = custShipCountry;
      map["CUST_SHIP_ZIP"] = custShipZip;
      map["CUST_SHIP_PHONE"] = custShipPhone;

      //Payment Details Field
      map["AMOUNT"] = (int.parse(amount) * 100).toString();
      map["CURRENCY_CODE"] = currencyCode;

      //Item Level Field
      map["PRODUCT_DESC"] = productDesc;

      ///end

      // debugPrint("getRequestParameter:  = $map");

      String separator = "&";
      String keyValueSeparator = "=";
      StringBuffer buffer = StringBuffer();

      map.forEach((key, value) {
        if(buffer.isNotEmpty){
          buffer.write(separator);
        }
        buffer.writeAll({key, value}, keyValueSeparator);
      });

      // debugPrint("getRequestParameter: buffer = $buffer");

      return buffer.toString();
    } catch (e) {
      // debugPrint("getRequestParameter: ${e}");

      return "";
    }
  }
}

==> 1.0.6.tar.gz: lib/model/paycaps_request.dart <==
part of paycaps;

class PayCapsRequest {
  //Merchant Details**
  String merPayId = "";
  String orderId = "";
  String returnUrl = "";
  String pgURL = "";
  String merKey = "";

  //Customer Details**
  String custName = "";
  String custFirstName = "";
  String custLastName = "";
  String custAddress = "";
  String custCity = "";
  String custState = "";
  String custCountry = "";
  String custZip = "";
  String merCustEmail = "";
  String merCustPhone = "";

  //Optional property
  String custShipFirstName = "";
  String custShipLastName = "";
  String custShipName = "";
  String custShipAddress1 = "";
  String custShipAddress2 = "";
  String custShipCity = "";
  String custShipState = "";
  String custShipCountry = "";
  String custShipZip = "";
  String custShipPhone = "";

  //Payment Details**
  String amount = "";
  String currencyCode = "";

  //Item Level Field**
  String productDesc = "";

  PayCapsRequest({
    this.merPayId = "",
    this.orderId = "",
    this.returnUrl = "",
    this.pgURL = "",
    this.merKey = "",
    this.custName = "",
    this.custFirstName = "",
    this.custLastName = "",
    this.custAddress = "",
    this.custCity = "",
    this.custState = "",
    this.custCountry = "",
    this.custZip = "",
    this.merCustEmail = "",
    this.merCustPhone = "",
    this.custShipFirstName = "",
    this.custShipLastName = "",
    this.custShipName = "",
    this.custShipAddress1 = "",
    this.custShipAddress2 = "",
    this.custShipCity = "",
    this.custShipState = "",
    this.custShipCountry = "",
    this.custShipZip = "",
    this.custShipPhone = "",
    this.amount = "",
    this.currencyCode = "",
    this.productDesc = "",
  });

  String getRequestParameter() {
    try {
      Map<String, String> map = LinkedHashMap<String, String>();


      //Required field name for merchant details
      map["APP_ID"] = merPayId;
      map["ORDER_ID"] = orderId;
      map["RETURN_URL"] = returnUrl;
      map["HASH"] = PayCapsGetHash256().generateCheckSum(map, merKey);


      //Customer Details
      map["CUST_NAME"] = custName;
      map["CUST_FIRST_NAME"] = custFirstName;
      map["CUST_LAST_NAME"] = custLastName;
      map["CUST_STREET_ADDRESS1"] = custAddress;
      map["CUST_CITY"] = custCity;
      map["CUST_STATE"] = custState;
      map["CUST_COUNTRY"] = custCountry;
      map["CUST_ZIP"] = custZip;
      map["CUST_EMAIL"] = merCustEmail;
      map["CUST_PHONE"] = merCustPhone;
      map["CUST_SHIP_LAST_NAME"] = custShipLastName;
      map["CUST_SHIP_FIRST_NAME"] = custShipFirstName;
      map["CUST_SHIP_NAME"] = custShipName;
      map["CUST_SHIP_STREET_ADDRESS1"] = custShipAddress1;
      map["CUST_SHIP_STREET_ADDRESS2"] = custShipAddress2;
      map["CUST_SHIP_CITY"] = custShipCity;
      map["CUST_SHIP_STATE"] = custShipState;
      map["CUST_SHIP_COUNTRY"] = custShipCountry;
      map["CUST_SHIP_ZIP"] = custShipZip;
      map["CUST_SHIP_PHONE"] = custShipPhone;

      //Payment Details Field
      // map["AMOUNT"] = (int.parse(amount) * 100).toString();
      map["AMOUNT"] = (double.parse(amount) * 100).toInt().toString();

      map["CURRENCY_CODE"] = currencyCode;

      //Item Level Field
      map["PRODUCT_DESC"] = productDesc;

      ///end

      // debugPrint("getRequestParameter:  = $map");

      String separator = "&";
      String keyValueSeparator = "=";
      StringBuffer buffer = StringBuffer();

      map.forEach((key, value) {
        if(buffer.isNotEmpty){
          buffer.write(separator);
        }
        buffer.writeAll({key, value}, keyValueSeparator);
      });

      // debugPrint("getRequestParameter: buffer = $buffer");

      return buffer.toString();
    } catch (e) {
      // debugPrint("getRequestParameter: ${e}");

      return "";
    }
  }
}
